#!/bin/bash
# (c) Copyright 2007-2013 Hewlett Packard Development Company, L.P.
# Version A.12.00.00
#
################################################################################
# Script that starts/stops an application server for SG/LX. 
# (As know as Toolkit Interface Script.)
#
# If the HA server scripts exist in the package directory, the server scripts 
# will be invoked.
#
# This script has one parameter passed to it, which then will be passed to the 
# HA server main script:
# - start   - to indicate the package is starting up
# - stop    - to indicate the package is shutting down
# - monitor - to indicate the package is monitoring the server
#
# This script eixts on one of the following code:
#  0: on success
#  1: on fail
#
################################################################################ 


HA_SERVER=HTTP
TKIT_SCRIPT_DIR=$SGROOT/apachetoolkit
HA_SCRIPT=$TKIT_SCRIPT_DIR/hahttp.sh
ACT=$1


# Function to test the return code
function test_return
{
    if (( $? != 0 ))
    then
        echo "ERROR: $(date '+%b %e %T') - Failed to $ACT $HA_SERVER."
        exit 1
    fi
}


# Function to log a warning message
function log_info
{
    if [[ "$ACT" = "start" ]]
    then
        echo -e "WARNING: The application script \"$HA_SCRIPT\" does not exist"
        echo -e "\t or is not executable. To run the application server on this node either"
        echo -e "\t install the script to $PW_DIR directory or use the chmod(1)"
        echo -e "\t command to make file $HA_SCRIPT executable. Then restart this package."
    else
        echo -e "WARNING: The application control script \"$HA_SCRIPT\" does not exist or"
        echo -e "\t is not excutable. Either install the script to $PW_DIR directory"
        echo -e "\t or use the chmod(1) command to make file $HA_SCRIPT executable"
        echo -e "\t (You may need to manually clean application resources.)"
    fi
}


# Invoke the application toolkit

if [ -x $HA_SCRIPT ]; then
    . $HA_SCRIPT $ACT
    test_return
else
    log_info
fi

exit 0
