#!/bin/bash
# (c) Copyright 2007-2014 Hewlett Packard Development Company, L.P.
# Version A.12.00.00

#####################################
# REVISION HISTORY
# A.04.02.02   10/19/2012   1) Added code changes to support online toolkit package modification 
# A.12.00.00   11/29/2013   1) Removed Toolkit Maintenance mode
#                           2) Removed Legacy package support
#                           3) Added Online reconfigure error check
#####################################

###########################
# Source utility functions.
###########################
	
 . /etc/cmcluster.conf
if [[ -z $SG_UTILS ]]; then
        SG_UTILS=$SGCONF/scripts/mscripts/utils.sh
fi

if [[ -f ${SG_UTILS} ]]; then
    . ${SG_UTILS}
    if (( $? != 0 ))
    then
        echo "ERROR: Unable to source package utility functions file: ${SG_UTILS}"
        exit 1
    fi
else
    echo "ERROR: Unable to find package utility functions file: ${SG_UTILS}"
    exit 1
fi

###################################################################
#
# Get the environment for this package through utility function
# sg_source_pkg_env().
#
###################################################################
export PATH=$PATH:$SGSBIN

sg_source_pkg_env $*

##################################################################
#
#       VALIDATE FUNCTION
#
#################################################################

function apache_validate
{
  #Add any validatins to be done here
  :
}

#############################################################
#
#       START FUNCTION
#
############################################################

function start_function
{
        . ${TKIT_SCRIPT_DIR}/toolkit.sh start
        exit_code=$?
}

#############################################################
#
#       STOP FUNCTION
#
############################################################

function stop_function
{

        . ${TKIT_SCRIPT_DIR}/toolkit.sh stop
        exit_code=$?

}

#############################################################
#
#       MONITOR FUNCTION
#
############################################################

function monitor_function
{
        . ${TKIT_SCRIPT_DIR}/toolkit.sh monitor
        exit_code=$?
}

############################################################
#
# RECONFIGURE STOP FUNCTION
#
############################################################


function reconfigure_stop_function
{
     if ! sg_check_if_reconfig_has_failed
     then
         if ! ${SGSBIN}/cmhaltserv ${service_name} ; then
             sg_log 999 "ERROR: Could not stop service: ${service_name}"
             sg_set_reconfig_failure
             exit_code=1 
         else
             sg_log 999 "SUCCESS: Successfully stopped service: $service_name"
             sg_log 0 "SUCCESS: Successfully stopped service: $service_name"
         fi    
     else
         sg_log 999 "WARNING: Not attempting to stop the service: ${service_name}"
     fi

}

############################################################
#
# RECONFIGURE START FUNCTION
#
############################################################

function reconfigure_start_function
{
         msg="cmrunserv: Unable to start service $service_name (it is already active)"
         out=`${SGSBIN}/cmrunserv ${service_name} "${service_cmd}" 2>&1`
         status=$? 
         if [[ $status -ne 0 ]] && [[ "$msg" != "$out" ]] ; then
            sg_log 999 "ERROR: Failed to start the service $service_name after online package modification"
            sg_set_reconfig_failure
            exit_code=1
         elif [[ $status -eq 0 ]] ; then
            sg_log 999 "SUCCESS: Successfully started service: $service_name"
            if ! sg_check_if_reconfig_has_failed ; then 
               sg_log 0 "SUCCESS: Successfully started service: $service_name" 
            fi
         fi
}
##################################
#
#Start of Routines
#
#################################

typeset -i exit_code=0
export TKIT_SCRIPT_DIR=$SGROOT/apachetoolkit
export HTTPD_CONFIG_FILE=$APACHE_HTTPD_CONFIG_FILE
export PID_FILE=$APACHE_PID_FILE
export FAIL_CRITERIA=$APACHE_FAIL_CRITERIA
export MONITOR_INTERVAL=$APACHE_MONITOR_INTERVAL
export RETRY_TIMES=$APACHE_RETRY_TIMES

if [[ $1 = "reconfigure_stop" || $1 = "reconfigure_start" ]]; then
    if [[ ${#SG_SERVICE_CMD[@]} -ne 0 ]]; then
        service_name=""
        service_cmd=""
        i=0
        for cmd in "${SG_SERVICE_CMD[@]}"
        do
            echo "$cmd" | grep "apache_monitor" >> /dev/null
            if [[ $? -eq 0 ]]
            then
                service_name=${SG_SERVICE_NAME[$i]}
                service_cmd="$cmd"
                break
            fi
            i=$i+1
        done
    fi
fi

case $1 in
        validate)
                apache_validate
                ;;

        start)
                if sg_check_if_reconfig_has_failed ; then
                    sg_log 999 "WARNING: Not attempting to start Apache module"
                    exit_code=1
                else
                    start_function
                    if [[ $exit_code -ne 0 ]] ; then
                       if sg_check_if_it_is_reconfiguration ; then
                          sg_log 999 "ERROR: Failed to start Apache module"
                          sg_set_reconfig_failure
                       fi                        
                    else
                       if sg_check_if_it_is_reconfiguration ; then
                          sg_log 999 "SUCCESS: Successfully started Apache module"
                       fi
                    fi
                fi

                ;;

        stop)
                stop_function
                ;;

        apache_monitor)
                monitor_function
                ;;
        reconfigure_stop)
                reconfigure_stop_function
                ;;
        reconfigure_start)
                reconfigure_start_function
                ;;
        *)
                sg_log 0 "Usage: ${0} [ start | stop | apache_monitor | validate | reconfigure_stop | reconfigure_start ]"
                ;;
esac

exit $exit_code
